//Регистрация решенных задач
function [err,msg]=RegisteredSolvedTask(SolvedTask,..//Решенна задача
                                        NextTasksNames,..//Последующие задачи
                                        ProjectName,..//Имя проекта
                                        errPrintMsg..//Необходимость печати сообщений об ошибках
                                        )
    //Проверяем аргументы
    nArg = argn(2);//Число аргументов
    if nArg < 2 then
        error('The function RegisteredSolvedTask takes 2, 3, or 4 arguments');
    end
    select nArg
    case 2 then
        ProjectName = "";//Имя проекта по умолчанию отсутcтвует
        errPrintMsg = %t;//По умолчанию печатаем сообщение об ошибках
    case 3 then
        if type(ProjectName) == 4 then
            errPrintMsg = ProjectName;
            ProjectName = "";//Имя проекта по умолчанию отсутcтвует
        else
            errPrintMsg = %t;//По умолчанию печатаем сообщения об ошибках
        end
    end
    
    //Формируем полное имя файла файла решенной задачи
    fullSolvedTaskNameFile = GetFullServiceDataFileName('d_' + SolvedTask + '.csv',..
                                                        ProjectName,errPrintMsg);
    
    //Делаем задачу недоступной
    try
        csvTaskDependence = csvRead(fullSolvedTaskNameFile,',','.','string');//Считывем задачу
    catch
        err = 1;
        msg = lasterror();
        if errPrintMsg then
            error(msg);
        else
            return;
        end
    end
    csvTaskDependence(2,$) = '0';
    try
        csvWrite(csvTaskDependence,fullSolvedTaskNameFile,',');//Сохраняем задачу
    catch
        err = 1;
        msg = lasterror();
        if errPrintMsg then
            error(msg);
        else
            return;
        end
    end
    
    //Корректируем составляющие доступности у последующих задач
    NextTasksNames = stripblanks(matrix(NextTasksNames,1,-1));
    for TaskName=NextTasksNames
        //Формируем полное имя файла задачи
        fullTaskNameFile = GetFullServiceDataFileName('d_' + TaskName + '.csv',..
                                                      ProjectName,errPrintMsg);
        
        //Считываем содержимое файла задач
        try
            csvTaskDependence = csvRead(fullTaskNameFile,',','.','string');
        catch
            err = 1;
            msg = lasterror();
            if errPrintMsg then
                error(msg);
            else
                return;
            end
        end
        
        //Корректируем составляющие разрешимости
        if csvTaskDependence(2,$) ~= '1' then
            SolvedTaskInd = (csvTaskDependence(1,:) == SolvedTask);//Индекс решенной задачи
            csvTaskDependence(2,SolvedTaskInd) = '1';
            if and(csvTaskDependence(2,1:($-1)) == '1') then
                csvTaskDependence(2,1:($-1)) = string(zeros(csvTaskDependence(2,1:($-1))));
                csvTaskDependence(2,$) = '1';
            end
            
            //Сохраняем скорректированное содержимое файла задач
            try
                csvWrite(csvTaskDependence,fullTaskNameFile,',');
            catch
                err = 1;
                msg = lasterror();
                if errPrintMsg then
                    error(msg);
                else
                    return;
                end
            end
        end
    end
    
    //Выводим положительный результат
    err = 0;
    msg = "";
endfunction
