//Регистрация решенных задач
function [err,msg]=RegisteredSolvedTaskMsg(SolvedTask,..//Решенна задача
                                           SolvedTaskMsgs,..//Сообщение решенной задачи
                                           ProjectName,..//Имя проекта
                                           errPrintMsg..//Необходимость печати сообщений об ошибках
                                           )
    //Проверяем аргументы
    nArg = argn(2);//Число аргументов
    if nArg < 2 then
        error('The function RegisteredSolvedTaskMsg 2, 3, or 4 arguments');
    end
    select nArg
    case 2 then
        ProjectName = "";//Имя проекта по умолчанию отсутcтвует
        errPrintMsg = %t;//По умолчанию печатаем сообщение об ошибках
    case 3 then
        if type(ProjectName) == 4 then
            errPrintMsg = ProjectName;
            ProjectName = "";//Имя проекта по умолчанию отсутcтвует
        else
            errPrintMsg = %t;//По умолчанию печатаем сообщения об ошибках
        end
    end
    
    //Извлекаем из строк последующие задачи, для которых готовы данные
    NextTasksNames = [];//Имена последующих задач, для которых готовы данные
    for SolvedTaskMsg=matrix(SolvedTaskMsgs,1,-1)
        //Получаем заголовок
        Header = matrix(stripblanks(strsplit(SolvedTaskMsg,':')),1,-1);//Заголовок и сами задачи
        if size(Header,'*') > 1 then
            strTasks = Header(2);
            Header(2:$) = [];//оставляем заголовок
        else
            strTasks = [];
        end
        if Header ~= 'Reseivig datas for solving next tasks' then
            NextTasksNames = [];
            err = 3;
            msg = 'The task ' + SolvedTask + ' was solved with error';
            if errPrintMsg then
                error(msg);
            else
                return;
            end
        end
        if ~isempty(strTasks) then
            strTasks = matrix(stripblanks(strsplit(strTasks,',')),1,-1);//Выделяем имена задач
            strTasks = strTasks(length(strTasks) > 0);
        end
        NextTasksNames = [NextTasksNames,strTasks];//Добавляем в общие имена задач
    end
    NextTasksNames = unique(NextTasksNames);//Удаляем повторяющиеся элементы
    
    //Регистрируем полученные задачи
    [err,msg]=RegisteredSolvedTask(SolvedTask,NextTasksNames,..
                                   ProjectName,errPrintMsg);
endfunction
